
#ifndef _C11_et548_
#define _C11_et548_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1447_13511(EIF_REFERENCE);
extern void EIF_Minit548(void);

#ifdef __cplusplus
}
#endif

#endif
